mkdir build

cd build

cmake ^
    -DCMAKE_PREFIX_PATH=%LIBRARY_PREFIX% ^
    -DCMAKE_BUILD_TYPE=Release ^
    -DBUILD_JAVA=False ^
    -DLZ4_HOME=%LIBRARY_PREFIX% ^
    -DZLIB_HOME=%LIBRARY_PREFIX% ^
    -DCMAKE_POLICY_DEFAULT_CMP0074=NEW ^
    -DProtobuf_ROOT=%LIBRARY_PREFIX% ^
    -DPROTOBUF_HOME=%LIBRARY_PREFIX% ^
    -DSNAPPY_HOME=%LIBRARY_PREFIX% ^
    -DBUILD_LIBHDFSPP=NO ^
    -DBUILD_CPP_TESTS=ON ^
    -DCMAKE_INSTALL_PREFIX=%LIBRARY_PREFIX% ^
    -DCMAKE_C_COMPILER=%CC%% ^
    -DCMAKE_CXX_COMPILER=%CXX% ^
    -DCMAKE_C_FLAGS="%CFLAGS%" ^
    -DCMAKE_CXX_FLAGS="%CXXFLAGS%" ^
    -GNinja ..

ninja
ninja package install
